#ifndef _LIBFOO_H
#define _LIBFOO_H

int foo(void);

#endif  /* _LIBFOO_H */
